//
//  RootViewController.m
//  APXMLSample
//
//  Created by Min-gu, Kim on 10. 8. 5..
//  Copyright 더블가이 2010. All rights reserved.
//

#import "RootViewController.h"


@implementation RootViewController

@synthesize itemArray;

#pragma mark -
#pragma mark View lifecycle

- (void)viewDidLoad {
    [super viewDidLoad];

    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    // self.navigationItem.rightBarButtonItem = self.editButtonItem;
	itemArray = [[NSMutableArray alloc] init];
	[self setTitle:@"APXML Test"];
}

- (void) processWebResponse:(NSData*) data {
	NSString *xmlStr = [[NSString alloc] initWithData:data encoding:NSUTF8StringEncoding];
	
	APDocument*	doc			= [APDocument documentWithXMLString:xmlStr];
	APElement*	rootElement	= [doc rootElement];
	
	NSArray* childElements = [rootElement childElements];
	
	for(APElement* child in childElements) {
		if([[child name] isEqualToString:@"channel"] == YES) {
			[self setItems:child];
		}
	}
}

- (void)setItems:(APElement *)channel {
	[itemArray removeAllObjects];
	
	NSArray* childElements = [channel childElements];
	for(APElement* child in childElements) {
		if([[child name] isEqualToString:@"item"] == YES) {
			[itemArray addObject:[self getItem:child]];
		}
	}
	
	[[self tableView] reloadData];
}

- (item *)getItem:(APElement *)itemElement {
	NSArray* childElements = [itemElement childElements];
	
	item* obj = [[[item alloc] init] autorelease];
	
	for(APElement* child in childElements) {
		if([[child name] isEqualToString:@"title"] == YES) {
			[obj setTitle:[child value]];
		}
		if([[child name] isEqualToString:@"description"] == YES) {
			[obj setDescription:[child value]];
		}
		if([[child name] isEqualToString:@"link"] == YES) {
			[obj setLink:[child value]];
		}
	}
	
	return obj;
}

- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];	
	
	NSURL*	url = [NSURL URLWithString:@"http://media.daum.net/rss/part/primary/digital/rss2.xml"];
	NSMutableURLRequest*	request = [[NSMutableURLRequest alloc] initWithURL:url];
	
	NSURLResponse*	urlResponse = nil;
	NSError* error = nil;
	NSData* data = [NSURLConnection sendSynchronousRequest:request returningResponse:&urlResponse error:&error];
		
	[self processWebResponse:data];
}


#pragma mark -
#pragma mark Table view data source

// Customize the number of sections in the table view.
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
	return 1;
}


// Customize the number of rows in the table view.
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [itemArray count];
}


// Customize the appearance of table view cells.
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    static NSString *CellIdentifier = @"Cell";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier] autorelease];
    }
    
	// Configure the cell.
	NSLog(@"indexPath.row = %i", indexPath.row);
	item* obj = (item *)[itemArray objectAtIndex:indexPath.row];
	[[cell textLabel] setText:[obj title]];
	
    return cell;
}


#pragma mark -
#pragma mark Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    
	item* obj = [itemArray objectAtIndex:indexPath.row];
	
	DescriptionViewController* vc = [[DescriptionViewController alloc] initWithNibName:@"DescriptionViewController" bundle:nil];

	[self.navigationController pushViewController:vc animated:YES];
	[vc loadDescriptionString:obj];
	[vc release];
	
}


#pragma mark -
#pragma mark Memory management

- (void)didReceiveMemoryWarning {
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Relinquish ownership any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
    // Relinquish ownership of anything that can be recreated in viewDidLoad or on demand.
    // For example: self.myOutlet = nil;
	itemArray = nil;
}


- (void)dealloc {
	[itemArray release];
	
    [super dealloc];
}


@end

